pub struct DecisionTreeClassifier<F> {
pub max_depth: Option<usize>,
pub min_samples_split: usize,
pub min_samples_leaf: usize,
pub criterion: ClassificationCriterion,
/* private fields */
}Expand description
CART decision tree classifier.
Builds a binary tree by recursively finding the feature and threshold that maximises the reduction in the chosen impurity criterion (Gini or Entropy).
Type Parameters
F: The floating-point type (f32orf64).
Fields
max_depth: Option<usize>Maximum depth of the tree. None means unlimited.
min_samples_split: usizeMinimum number of samples required to split an internal node.
min_samples_leaf: usizeMinimum number of samples required in a leaf node.
criterion: ClassificationCriterionSplitting criterion.
Implementations
Sourceimpl<F: Float> DecisionTreeClassifier<F>
impl<F: Float> DecisionTreeClassifier<F>
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new DecisionTreeClassifier with default settings.
Defaults: max_depth = None, min_samples_split = 2,
min_samples_leaf = 1, criterion = Gini.
Sourcepub fn with_max_depth(self, max_depth: Option<usize>) -> Self
pub fn with_max_depth(self, max_depth: Option<usize>) -> Self
Set the maximum tree depth.
Sourcepub fn with_min_samples_split(self, min_samples_split: usize) -> Self
pub fn with_min_samples_split(self, min_samples_split: usize) -> Self
Set the minimum number of samples required to split a node.
Sourcepub fn with_min_samples_leaf(self, min_samples_leaf: usize) -> Self
pub fn with_min_samples_leaf(self, min_samples_leaf: usize) -> Self
Set the minimum number of samples required in a leaf node.
Sourcepub fn with_criterion(self, criterion: ClassificationCriterion) -> Self
pub fn with_criterion(self, criterion: ClassificationCriterion) -> Self
Set the splitting criterion.